const rewire = require('rewire');
const R = require('ramda');
const chai = require('chai');
const {describe} = require('mocha');

chai.should();
chai.use(require('sinon-chai'));

const KafkaIndexRw = rewire('../index.js');

describe('index.js', () => {
  describe('#stringifyMessageTopic_', () => {
    it('should return string list', () => {
      const stringifyMessageTopic_ = KafkaIndexRw.__get__('stringifyMessageTopic_');
      stringifyMessageTopic_('helheim', {
        message: {data: 'value'}
      }).should.be.eql('{"message":{"data":"value"},"to":"helheim"}');
    });
  });
  describe('#formatAllMessages_', () => {
    it('should return string list', () => {
      const formatAllMessages_ = KafkaIndexRw.__get__('formatAllMessages_');
      formatAllMessages_('helheim', [
        {
          message: {data: 'value'}
        },
        {
          message: {data: 'value2'}
        }
      ]).should.be.eql([
        '{"message":{"data":"value"},"to":"helheim"}',
        '{"message":{"data":"value2"},"to":"helheim"}'
      ]);
    });
  });
  describe('#getPayloadBase_', () => {
    it('should return string list', () => {
      const getPayloadBase_ = KafkaIndexRw.__get__('getPayloadBase_');
      getPayloadBase_('helheim', 'Vanaheim', [
        {
          message: {data: 'value'}
        },
        {
          message: {data: 'value2'}
        }
      ]).should.be.eql({
        messages: [
          '{"message":{"data":"value"},"to":"helheim"}',
          '{"message":{"data":"value2"},"to":"helheim"}'
        ],
        topic: 'Vanaheim'
      });
    });
  });
  describe('#getPayload_', () => {
    it('should return string list', () => {
      const getPayload_ = KafkaIndexRw.__get__('getPayload_');
      getPayload_('helheim', 'Vanaheim', [
        {
          message: {data: 'value'}
        },
        {
          message: {data: 'value2'}
        }
      ]).should.be.eql([{
        messages: [
          '{"message":{"data":"value"},"to":"helheim"}',
          '{"message":{"data":"value2"},"to":"helheim"}'
        ],
        topic: 'Vanaheim'
      }]);
    });
  });
  describe('#getPayloadWithKey_', () => {
    it('should return string list', () => {
      const getPayloadWithKey_ = KafkaIndexRw.__get__('getPayloadWithKey_');
      const result = getPayloadWithKey_('helheim', 'Vanaheim', [
        {
          message: {data: 'value'}
        },
        {
          message: {data: 'value2'}
        }
      ], {key: 'aaaaa', partition: 0});
      const timestamp = R.prop('timestamp', R.head(R.prop('messages', R.head(result))));
      result.should.be.eql([{
        messages: [

          {
            attributes: 0,
            key: 'aaaaa',
            magic: 0,
            timestamp,
            value: '{"message":{"data":"value"},"to":"helheim"}'
          },
          {
            attributes: 0,
            key: 'aaaaa',
            magic: 0,
            timestamp,
            value: '{"message":{"data":"value2"},"to":"helheim"}'
          }
        ],
        topic: 'Vanaheim',
        key: 'aaaaa',
        partition: 0
      }]);
    });
  });
  describe('#getOptionPartitionType_', () => {
    it('should return object', () => {
      const getOptionPartitionType_ = KafkaIndexRw.__get__('getOptionPartitionType_');
      getOptionPartitionType_('cyclic').should.be.eql({partitionerType: 2});
    });
    it('should return object', () => {
      const getOptionPartitionType_ = KafkaIndexRw.__get__('getOptionPartitionType_');
      getOptionPartitionType_('random').should.be.eql({partitionerType: 1});
    });
    it('should return object', () => {
      const getOptionPartitionType_ = KafkaIndexRw.__get__('getOptionPartitionType_');
      getOptionPartitionType_('randoms').should.be.eql({});
    });
  });
});
